
Installation
============
To install the **latest release**, run::

    pip install cloup

Cloup adheres to `semantic versioning <https://semver.org/>`_.

.. important::
    Since Cloup has not reached v1.0, its API is not to be considered stable.
    This doesn't mean you can't already use it: it is already extensively tested
    and documented. Just make sure you pin the version you are using in your
    requirements file, e.g.

    .. parsed-literal::

        cloup ~= \ |release|\

    Patch releases are guaranteed to be backward-compatible even before v1.0.

    At each new release, you can check the :doc:`changelog` to see what's changed.

